## Ansættelseskontrakt

Mellem undertegnede

<company-name>GreenTaste Café IVS</company-name>

Nørregade 8, st., 7570 Vemb  
CVR-nr.: 41029876 (herefter kaldet virksomheden)

og medundertegnede

## Selma Højbjerg

Lindehøjen 27, 2. mf., 4622 Havdrup (herefter kaldet medarbejderen)

indgås følgende ansættelseskontrakt:

<start-date>
## [SECTION-IDX]. Tiltrædelsestidspunkt

Medarbejderen tiltræder stillingen med virkning fra 10.08.2024.
</start-date>

<title>
## [SECTION-IDX]. Stillingsbetegnelse

Medarbejderen varetager funktionen som Barista.
</title>

<location>
## [SECTION-IDX]. Arbejdssted

Det faste arbejdssted er Nørregade 8, st., 8560 Kolind.
</location>

## [SECTION-IDX]. Arbejdsopgaver

Arbejdsopgaverne omfatter tilberedning af kaffe- og specialdrikke, kundeservice samt lettere rengøringsopgaver i caféen. Arbejdsopgaverne kan ændres i takt med virksomhedens behov.

<trial-period>
## [SECTION-IDX]. Prøvetid

Der er ikke aftalt nogen prøvetid for denne ansættelse.
</trial-period>

<salary>
## [SECTION-IDX]. Løn

Den faste årlige bruttoløn er kr. 276.000, svarende til kr. 23.000 pr. måned før skat, pension og andre lovpligtige bidrag. Lønnen udbetales månedsvis bagud til medarbejderens konto den sidste bankdag i måneden.
</salary>

<pension>
## [SECTION-IDX]. Pension

Der oprettes pensionsordning i AP Pension. Virksomheden indbetaler 3% og medarbejderen indbetaler 1% af den ferieberettigede løn til pensionsordningen.
</pension>

<social-security>
## [SECTION-IDX]. Sociale sikringsbidrag

Virksomheden indbetaler alle lovpligtige sociale sikringsbidrag i overensstemmelse med dansk lovgivning, herunder ATP, barselsfond m.m.
</social-security>

<work-time>
## [SECTION-IDX]. Arbejdstid

Den gennemsnitlige ugentlige arbejdstid udgør 37 timer. Arbejdstiden fordeles efter nærmere aftale og inden for virksomhedens normale åbningstid. I lønnen er indregnet eventuelt nødvendigt overarbejde, og der gives ikke særskilt betaling herfor, medmindre andet aftales.
</work-time>

<holiday>
## [SECTION-IDX]. Ferie

Medarbejderen har ret til ferie med løn efter ferielovens regler. Særligt ferietillæg udbetales i henhold til lovgivningen.
</holiday>

<extra-holiday>
## [SECTION-IDX]. Ekstra feriefridage

Medarbejderen har ikke ret til ekstra feriefridage ud over ferielovens bestemmelser.
</extra-holiday>

<training>
## [SECTION-IDX]. Efteruddannelse

Medarbejderen tilbydes relevante kurser eller efteruddannelse efter nærmere aftale, og efter virksomhedens behov samt gældende overenskomst.
</training>

<illness>
## [SECTION-IDX]. Sygdom

Ved sygdom meddeles dette straks til virksomheden. Virksomheden kan kræve dokumentation ved længerevarende sygefravær. Medarbejderen er berettiget til løn under sygdom i henhold til gældende regler.
</illness>

<parental-leave>
## [SECTION-IDX]. Barsel, graviditet og forældreorlov

Ved graviditet og fødsel er medarbejderen berettiget til orlov efter gældende barselsregler:

- Mor har ret til fravær med løn i op til 4 uger før fødsel og op til 14 uger efter fødsel.
- Far/medmor har ret til 2 ugers fravær med løn umiddelbart efter fødslen.

Orlov kan aftales yderligere i henhold til gældende lovgivning.

Ved barns sygdom har medarbejderen ret til frihed med løn i op til 1 dag pr. barn pr. år.
</parental-leave>

<termination>
## [SECTION-IDX]. Opsigelse

Ansættelsesforholdet kan fra begge parters side opsiges med 14 dages varsel til en hvilken som helst dag, med mindre længere varsler følger af funktionærlovens eller overenskomstens regler. Opsigelse skal ske skriftligt.
</termination>

<collective-agreement>
## [SECTION-IDX]. Kollektiv overenskomst

Ansættelsesforholdet er omfattet af overenskomsten med 3F - Privat Service, Hotel og Restauration.
</collective-agreement>

## [SECTION-IDX]. Retsgrundlag

Ansættelsen er reguleret af dansk ret med respekt af funktionær- og ferielovens bestemmelser, samt den til enhver tid gældende overenskomst, i det omfang det er relevant for ansættelsesforholdet.

Kolind, den 08.06.2024

Medarbejderen _____________________________________

Virksomheden _____________________________________